# coding: utf-8

"""
    Schul-Cloud Content API

    This is the specification for the content of Schul-Cloud. You can find more information in the [repository](https://github.com/schul-cloud/resources-api-v1). 

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .error_element import ErrorElement
from .error_response import ErrorResponse
from .jsonapi import Jsonapi
from .jsonapi_meta import JsonapiMeta
from .resource import Resource
from .resource_ids_response import ResourceIdsResponse
from .resource_ids_response_data import ResourceIdsResponseData
from .resource_ids_response_links import ResourceIdsResponseLinks
from .resource_post import ResourcePost
from .resource_post_data import ResourcePostData
from .resource_response import ResourceResponse
from .resource_response_data import ResourceResponseData
from .resource_response_links import ResourceResponseLinks
from .resource_type import ResourceType
