# coding: utf-8

"""
    Schul-Cloud Content API

    This is the specification for the content of Schul-Cloud. You can find more information in the [repository](https://github.com/schul-cloud/resources-api-v1). 

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import schul_cloud_resources_api_v1
from schul_cloud_resources_api_v1.rest import ApiException
from schul_cloud_resources_api_v1.apis.resource_api import ResourceApi


class TestResourceApi(unittest.TestCase):
    """ ResourceApi unit test stubs """

    def setUp(self):
        self.api = schul_cloud_resources_api_v1.apis.resource_api.ResourceApi()

    def tearDown(self):
        pass

    def test_add_resource(self):
        """
        Test case for add_resource

        Add new resources to the database
        """
        pass

    def test_delete_resource(self):
        """
        Test case for delete_resource

        Delete a resource
        """
        pass

    def test_delete_resources(self):
        """
        Test case for delete_resources

        Delete all resources
        """
        pass

    def test_get_resource(self):
        """
        Test case for get_resource

        Get a resource.
        """
        pass

    def test_get_resource_ids(self):
        """
        Test case for get_resource_ids

        Get the ids of all resources of the client
        """
        pass


if __name__ == '__main__':
    unittest.main()
